@@ -97,7 +97,8 @@ def pylsp_settings():
             "pyflakes": {"enabled": False},
             "mccabe": {"enabled": False},
             "pycodestyle": {"enabled": False},
-            "pyls_isort": {"enabled": False},
+            "yapf": {"enabled": False},
+            "autopep8": {"enabled": False},
         }
     }
     return converter.unstructure(settings)
